@@ -5,6 +5,7 @@
 # ggproto objects for these are defined in a later chunk.
 
 #' @include ggplot2.r
+#' @include coord-cartesian.r
 NULL
 
 #' Cartesian coordinates with flexible options for drawing axes
@@ -20,8 +21,7 @@ NULL
 #'
 #' @section User defined functions:
 #' The provided function in \code{top}, \code{right}, \code{bottom}, and \code{left}
-#' defaults to \code{render_axis} which is defined in \file{ggplot2/R/coord-.r}, which in
-#' turns calls \code{guide_axis} (see \file{ggplot2/R/guides-axis.r}).
+#' defaults to \code{panel_guides_grob} which is defined in \file{gR/coord-cartesian.r}.
 #'
 #' The provided function is with the arguments
 #' \code{scale_details}, \code{axis}, \code{scale}, \code{position}, and \code{theme},
@@ -97,8 +97,14 @@ coord_flex_cart <- function(xlim = NULL,
 
 #' @rdname coord_flex
 #' @export
-#' @inheritParams  coord_flex_cart
-#'
+# @inheritParams  coord_flex_cart
+#' @param top,left,bottom,right Function for drawing axis lines, ticks, and labels,
+#'    use e.g. \code{\link{capped_horizontal}} or \code{\link{brackets_horizontal}}.
+#  @inheritParams coord_cartesian
+#' @param xlim,ylim Limits for the x and y axes.
+#' @param expand If \code{TRUE}, the default, adds a small expansion factor to
+#'   the limits to ensure that data and axes don't overlap. If \code{FALSE},
+#'   limits are taken exactly from the data or \code{xlim}/\code{ylim}.
 coord_flex_flip <- function(xlim = NULL,
                             ylim = NULL,
                             expand = TRUE,
@@ -120,9 +126,16 @@ coord_flex_flip <- function(xlim = NULL,
 }
 
 #' @rdname coord_flex
-#' @inheritParams  coord_flex_cart
 #' @export
 #' @param ratio aspect ratio, expressed as \code{y / x}.
+# @inheritParams  coord_flex_cart
+#' @param top,left,bottom,right Function for drawing axis lines, ticks, and labels,
+#'    use e.g. \code{\link{capped_horizontal}} or \code{\link{brackets_horizontal}}.
+#  @inheritParams coord_cartesian
+#' @param xlim,ylim Limits for the x and y axes.
+#' @param expand If \code{TRUE}, the default, adds a small expansion factor to
+#'   the limits to ensure that data and axes don't overlap. If \code{FALSE},
+#'   limits are taken exactly from the data or \code{xlim}/\code{ylim}.
 coord_flex_fixed <- function(ratio = 1,
                              xlim = NULL,
                              ylim = NULL,
@@ -155,21 +168,21 @@ coord_flex_fixed <- function(ratio = 1,
 # For each top/bottom or left/right axis, they basically just call what ever
 # function the coord_flex classes were given.
 flex_render_axis_h <- function(self, scale_details, theme) {
-  arrange <- scale_details$x.arrange %||% c("primary", "secondary")
-  top <- self$top %|W|% render_axis
-  bottom <- self$bottom %|W|% render_axis
+  top <- self$top %|W|% panel_guides_grob
+  bottom <- self$bottom %|W|% panel_guides_grob
   list(
-    top = top(scale_details, arrange[1], "x", "top", theme),
-    bottom = bottom(scale_details, arrange[2], "x", "bottom", theme)
+    #top = top(scale_details, arrange[1], "x", "top", theme),
+    #bottom = bottom(scale_details, arrange[2], "x", "bottom", theme)
+    top = top(scale_details$guides, position = "top", theme = theme),
+    bottom = bottom(scale_details$guides, position = "bottom", theme = theme)
   )
 }
 flex_render_axis_v <- function(self, scale_details, theme) {
-  arrange <- scale_details$y.arrange %||% c("primary","secondary")
-  left <- self$left %|W|% render_axis
-  right <- self$right %|W|% render_axis
+  left <- self$left %|W|% panel_guides_grob
+  right <- self$right %|W|% panel_guides_grob
   list(
-    left = left(scale_details, arrange[1], 'y', 'left', theme),
-    right = right(scale_details, arrange[2], 'y', 'right', theme)
+    left = left(scale_details$guides, position = 'left', theme),
+    right = right(scale_details$guides, position = 'right', theme)
   )
 }
 
